@@ -30,12 +30,12 @@ describe 'ironic::db::postgresql' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
 
-      it_configures 'ironic::db::postgresql'
+      it_behaves_like 'ironic::db::postgresql'
     end
   end
 
