@@ -41,9 +41,8 @@ describe 'ironic::glance' do
       is_expected.to contain_ironic_config('glance/password').with_value('<SERVICE DEFAULT>').with_secret(true)
       is_expected.to contain_ironic_config('glance/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_config('glance/project_domain_name').with_value('Default')
-      is_expected.to contain_ironic_config('glance/glance_api_servers').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/glance_api_insecure').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/glance_num_retries').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('glance/insecure').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('glance/num_retries').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('glance/swift_account').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('glance/swift_container').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('glance/swift_endpoint_url').with(:value => '<SERVICE DEFAULT>')
@@ -82,9 +81,8 @@ describe 'ironic::glance' do
         is_expected.to contain_ironic_config('glance/password').with_value(p[:password]).with_secret(true)
         is_expected.to contain_ironic_config('glance/user_domain_name').with_value(p[:user_domain_name])
         is_expected.to contain_ironic_config('glance/project_domain_name').with_value(p[:project_domain_name])
-        is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(p[:api_servers])
-        is_expected.to contain_ironic_config('glance/glance_api_insecure').with_value(p[:api_insecure])
-        is_expected.to contain_ironic_config('glance/glance_num_retries').with_value(p[:num_retries])
+        is_expected.to contain_ironic_config('glance/insecure').with_value(p[:api_insecure])
+        is_expected.to contain_ironic_config('glance/num_retries').with_value(p[:num_retries])
         is_expected.to contain_ironic_config('glance/swift_account').with_value(p[:swift_account])
         is_expected.to contain_ironic_config('glance/swift_container').with_value(p[:swift_container])
         is_expected.to contain_ironic_config('glance/swift_endpoint_url').with_value(p[:swift_endpoint_url])
@@ -94,38 +92,6 @@ describe 'ironic::glance' do
       end
     end
 
-    context 'when overriding parameters with 2 glance servers' do
-      before :each do
-        params.merge!(
-            :auth_type           => 'noauth',
-            :auth_url            => 'http://example.com',
-            :project_name        => 'project1',
-            :username            => 'admin',
-            :password            => 'pa$$w0rd',
-            :user_domain_name    => 'NonDefault',
-            :project_domain_name => 'NonDefault',
-            :api_servers         => ['10.0.0.1:9292','10.0.0.2:9292'],
-            :api_insecure        => true,
-            :num_retries         => 42,
-            :endpoint_override   => 'http://example2.com',
-        )
-      end
-
-      it 'should replace default parameter with new value' do
-        is_expected.to contain_ironic_config('glance/auth_type').with_value(p[:auth_type])
-        is_expected.to contain_ironic_config('glance/auth_url').with_value(p[:auth_url])
-        is_expected.to contain_ironic_config('glance/project_name').with_value(p[:project_name])
-        is_expected.to contain_ironic_config('glance/username').with_value(p[:username])
-        is_expected.to contain_ironic_config('glance/password').with_value(p[:password]).with_secret(true)
-        is_expected.to contain_ironic_config('glance/user_domain_name').with_value(p[:user_domain_name])
-        is_expected.to contain_ironic_config('glance/project_domain_name').with_value(p[:project_domain_name])
-        is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(p[:api_servers].join(','))
-        is_expected.to contain_ironic_config('glance/glance_api_insecure').with_value(p[:api_insecure])
-        is_expected.to contain_ironic_config('glance/glance_num_retries').with_value(p[:num_retries])
-        is_expected.to contain_ironic_config('glance/endpoint_override').with_value(p[:endpoint_override])
-      end
-    end
-
     context 'when overriding parameters swift_account_project_name' do
       before :each do
         params.merge!(
