@@ -96,7 +96,7 @@ describe 'ironic' do
     it 'should perform default database configuration' do
       is_expected.to contain_ironic_config('database/connection').with_value(params[:database_connection])
       is_expected.to contain_ironic_config('database/max_retries').with_value(params[:database_max_retries])
-      is_expected.to contain_ironic_config('database/idle_timeout').with_value(params[:database_idle_timeout])
+      is_expected.to contain_ironic_config('database/connection_recycle_time').with_value(params[:database_idle_timeout])
       is_expected.to contain_ironic_config('database/retry_interval').with_value(params[:database_retry_interval])
     end
 
@@ -105,11 +105,13 @@ describe 'ironic' do
       is_expected.to contain_ironic_config('DEFAULT/my_ip').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/executor_thread_pool_size').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('DEFAULT/rpc_transport').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>').with_secret(true)
       is_expected.to contain_ironic_config('DEFAULT/default_resource_class').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/notification_level').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/versioned_notifications_topics').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
     end
   end
 
@@ -250,6 +252,18 @@ describe 'ironic' do
     end
   end
 
+  shared_examples_for 'oslo messaging remote procedure call' do
+    context 'with overridden rpc parameters' do
+      before { params.merge!(
+        :rpc_transport        => 'pigeons',
+        :rpc_response_timeout => '3628800',
+      ) }
+
+      it { is_expected.to contain_ironic_config('DEFAULT/rpc_transport').with_value('pigeons') }
+      it { is_expected.to contain_ironic_config('DEFAULT/rpc_response_timeout').with_value('3628800') }
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
