@@ -46,11 +46,13 @@ describe 'ironic::inspector' do
       :swift_tenant_name     => 'services',
       :swift_auth_url        => 'http://127.0.0.1:5000/v3',
       :dnsmasq_ip_subnets    => [{ 'ip_range' =>
-                                      '192.168.0.100,192.168.0.120' },
+                                      '192.168.0.100,192.168.0.120',
+                                   'mtu' => '1350'},
                                  { 'tag'      => 'subnet1',
                                    'ip_range' => '192.168.1.100,192.168.1.200',
                                    'netmask'  => '255.255.255.0',
-                                   'gateway'  => '192.168.1.254' },
+                                   'gateway'  => '192.168.1.254',
+                                   'mtu'      => '1350'},
                                  { 'tag'                     => 'subnet2',
                                    'ip_range'                => '192.168.2.100,192.168.2.200',
                                    'netmask'                 => '255.255.255.0',
@@ -58,7 +60,11 @@ describe 'ironic::inspector' do
                                    'classless_static_routes' => [{'destination' => '1.2.3.0/24',
                                                                   'nexthop'     => '192.168.2.1'},
                                                                  {'destination' => '4.5.6.0/24',
-                                                                  'nexthop'     => '192.168.2.1'}]}],
+                                                                  'nexthop'     => '192.168.2.1'}]},
+                                 { 'tag'      => 'subnet3',
+                                   'ip_range' => '2001:4888:a03:313a:c0:fe0:0:c200,2001:4888:a03:313a:c0:fe0:0:c2ff',
+                                   'netmask'  => 'ffff:ffff:ffff:ffff::',
+                                   'gateway'  => '2001:4888:a03:313a:c0:fe0:0:c000' }],
       :dnsmasq_local_ip      => '192.168.0.1',
       :ipxe_timeout          => 0,
       :http_port             => 8088,
@@ -149,12 +155,18 @@ describe 'ironic::inspector' do
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-range=192.168.0.100,192.168.0.120,10m/
       )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-option-force=option:mtu,1350/
+      )
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-range=set:subnet1,192.168.1.100,192.168.1.200,255.255.255.0,10m/
       )
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-option=tag:subnet1,option:router,192.168.1.254/
       )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-option-force=tag:subnet1,option:mtu,1350/
+      )
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-range=set:subnet2,192.168.2.100,192.168.2.200,255.255.255.0,10m/
       )
@@ -164,6 +176,12 @@ describe 'ironic::inspector' do
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-option=tag:subnet2,option:classless-static-route,1.2.3.0\/24,192.168.2.1,4.5.6.0\/24,192.168.2.1/
       )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-range=set:subnet3,2001:4888:a03:313a:c0:fe0:0:c200,2001:4888:a03:313a:c0:fe0:0:c2ff,64,10m/
+      )
+      is_expected.not_to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-option=tag:subnet3,option:router,2001:4888:a03:313a:c0:fe0:0:c000/
+      )
     end
     it 'should contain file /tftpboot/pxelinux.cfg/default' do
       is_expected.to contain_file('/tftpboot/pxelinux.cfg/default').with(
@@ -242,6 +260,12 @@ describe 'ironic::inspector' do
         is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
             /log-queries/
         )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-userclass=set:ipxe6,iPXE/
+        )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-option=tag:ipxe6,option6:bootfile-url,http:\/\/.*:3816\/inspector.ipxe/
+        )
       end
       it 'should contain file /var/www/httpboot/inspector.ipxe' do
         is_expected.to contain_file('/var/www/httpboot/inspector.ipxe').with(
@@ -269,6 +293,20 @@ describe 'ironic::inspector' do
               /kernel --timeout 30000/)
         end
       end
+
+      context 'when using ipv6' do
+        before :each do
+          params.merge!(
+            :listen_address     => 'fd00::1',
+          )
+        end
+
+        it 'should contain file /var/www/httpboot/inspector.ipxe' do
+          is_expected.to contain_file('/var/www/httpboot/inspector.ipxe').with_content(
+            /kernel http:\/\/\[fd00::1\]:3816\/agent.kernel ipa-inspection-callback-url=http:\/\/\[fd00::1\]:5050\/v1\/continue ipa-inspection-collectors=default.* foo=bar || goto retry_boot/
+          )
+        end
+      end
     end
 
     context 'when enabling ppc64le support' do
