@@ -132,11 +132,28 @@ describe 'ironic::pxe' do
           :syslinux_path => false,
         )
       end
-      it 'should not contain package syslinux' do
-        is_expected.not_to contain_package('syslinux')
+      it 'should not contain package syslinux-tftpboot' do
+        is_expected.not_to contain_package('syslinux-tftpboot')
       end
       it 'should not contain tftpboot syslinux file' do
-        is_expected.not_to contain_file('/tftpboot/pxelinux.0')
+        is_expected.not_to contain_file('/var/lib/ironic/tftpboot/pxelinux.0')
+      end
+    end
+
+    context 'when enabling ppc64le support' do
+      before :each do
+        params.merge!(
+          :enable_ppc64le => true,
+        )
+      end
+      it 'should contain directory /tftpboot/ppc64le with selinux type tftpdir_t' do
+        is_expected.to contain_file('/tftpboot/ppc64le').with(
+          'owner'   => 'ironic',
+          'group'   => 'ironic',
+          'require' => 'Anchor[ironic::install::end]',
+          'ensure'  => 'directory',
+          'seltype' => 'tftpdir_t',
+        )
       end
     end
   end
