@@ -94,14 +94,14 @@ describe 'ironic::wsgi::apache' do
               :httpd_service_name => 'apache2',
               :httpd_ports_file   => '/etc/apache2/ports.conf',
               :wsgi_script_path   => '/usr/lib/cgi-bin/ironic',
-              :wsgi_script_source => '/usr/lib/python3/dist-packages/ironic/api/app.wsgi',
+              :wsgi_script_source => '/usr/bin/ironic-api-wsgi',
             }
         when 'RedHat'
             {
               :httpd_service_name => 'httpd',
               :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
               :wsgi_script_path   => '/var/www/cgi-bin/ironic',
-              :wsgi_script_source => '/usr/lib/python2.7/site-packages/ironic/api/app.wsgi',
+              :wsgi_script_source => '/usr/bin/ironic-api-wsgi',
             }
         end
       end
